@@ -1,4 +1,4 @@
-from abc import ABC, abstractmethod
+from abc import ABC
 from typing import Callable, Sequence
 
 from fastapi import Depends
@@ -12,10 +12,6 @@ class Limiter(ABC):
     def __init__(self, strategy: Strategy):
         self._strategy = strategy
 
-    @abstractmethod
-    def __call__(self, *args, **kwargs):
-        """Limit the api based on rate."""
-
 
 class GlobalLimiter(Limiter):
     def __call__(self):
